telegram_game package
=====================

Submodules
----------

telegram_game.api module
------------------------

.. automodule:: telegram_game.api
    :members:
    :undoc-members:
    :show-inheritance:

telegram_game.cli module
------------------------

.. automodule:: telegram_game.cli
    :members:
    :undoc-members:
    :show-inheritance:

telegram_game.dispatcher module
-------------------------------

.. automodule:: telegram_game.dispatcher
    :members:
    :undoc-members:
    :show-inheritance:

telegram_game.game module
-------------------------

.. automodule:: telegram_game.game
    :members:
    :undoc-members:
    :show-inheritance:

telegram_game.messages module
-----------------------------

.. automodule:: telegram_game.messages
    :members:
    :undoc-members:
    :show-inheritance:

telegram_game.redis_game module
-------------------------------

.. automodule:: telegram_game.redis_game
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: telegram_game
    :members:
    :undoc-members:
    :show-inheritance:
